@@ -8,7 +8,7 @@
  *             Andrae Muys <andrae@humbug.org.au.au>
  *           - uses libbzip2 by Julian Seward (http://sources.redhat.com/bzip2/)
  *
- *	Date  : December 31, 2005
+ *	Date  : February 5, 2006
  *
  *
  *  Contributions
@@ -25,6 +25,7 @@
  *  Jindrich Novy <jnovy@redhat.com> - code cleanup and bug fixes
  *  Benjamin Reed <ranger@befunk.com> - autodetection for # of CPUs in OSX
  *  Chris Dearman <chris@mips.com> - fixed pthreads race condition
+ *  Richard Russon <ntfs@flatcap.org> - help fix decompression bug
  *
  *  Specials thanks for suggestions and testing:  Phillippe Welsh,
  *  James Terhune, Dru Lemley, Bryan Stillwell, George Chalissery,
@@ -33,7 +34,7 @@
  *  and Richard Russon.
  *
  *
- * This program, "pbzip2" is copyright (C) 2003-2005 Jeff Gilchrist.
+ * This program, "pbzip2" is copyright (C) 2003-2006 Jeff Gilchrist.
  * All rights reserved.
  *
  * The library "libbzip2" which pbzip2 uses, is copyright
@@ -72,7 +73,7 @@
  *
  * Jeff Gilchrist, Ottawa, Canada.
  * pbzip2@compression.ca
- * pbzip2 version 0.9.5 of December 31, 2005
+ * pbzip2 version 0.9.6 of February 5, 2006
  *
  */
 #include <vector>
@@ -249,7 +250,7 @@ char *memstr(char *searchBuf, int searchBufSize, char *searchString, int searchS
 
 	for (i=0; i < searchBufSize; i++)
 	{
-		if ((searchBufSize - 1 - i) < searchStringSize)
+		if ((searchBufSize - i) < searchStringSize)
 			break;
 
 		if (searchBuf[i] == searchString[0])
@@ -1389,8 +1390,8 @@ int writeFileMetaData(char *fileName)
  */
 void banner()
 {
-	fprintf(stderr, "Parallel BZIP2 v0.9.5 - by: Jeff Gilchrist [http://compression.ca]\n");
-	fprintf(stderr, "[Dec. 31, 2005]             (uses libbzip2 by Julian Seward)\n\n");
+	fprintf(stderr, "Parallel BZIP2 v0.9.6 - by: Jeff Gilchrist [http://compression.ca]\n");
+	fprintf(stderr, "[Feb. 05, 2006]             (uses libbzip2 by Julian Seward)\n\n");
 	fprintf(stderr, "** This is a BETA version - Use at your own risk! **\n");
 
 	return;
